
/*
 *
 * AutoIt v3 Plugin SDK - Example
 *
 * Copyright (C)1999-2007 Jonathan Bennett <jon at autoitscript com>
 *
 * example.c
 *
 */

#include "stdafx.h"
#include <windows.h>
#include <tchar.h>
#include <stdio.h>
#include <iostream>

#include "AU3_Plugin_SDK\au3plugin.h"


using namespace std;


//using namespace std;
/****************************************************************************
 * Function List
 *
 * This is where you define the functions available to AutoIt.  Including
 * the function name (Must be the same case as your exported DLL name), the
 * minimum and maximum number of parameters that the function takes.
 *
 ****************************************************************************/

/* "FunctionName", min_params, max_params */
AU3_PLUGIN_FUNC g_AU3_Funcs[] = 
{
	{"LoadHRDat", 0, 0},
	{"AnalyzeHand5", 5, 5},
	{"AnalyzeHand6", 6, 6},
	{"AnalyzeHand", 7, 7}
};


/****************************************************************************
 * AU3_GetPluginDetails()
 *
 * This function is called by AutoIt when the plugin dll is first loaded to
 * query the plugin about what functions it supports.  DO NOT MODIFY.
 *
 ****************************************************************************/

AU3_PLUGINAPI int AU3_GetPluginDetails(int *n_AU3_NumFuncs, AU3_PLUGIN_FUNC **p_AU3_Func)
{
	/* Pass back the number of functions that this DLL supports */
	*n_AU3_NumFuncs	= sizeof(g_AU3_Funcs)/sizeof(AU3_PLUGIN_FUNC);

	/* Pack back the address of the global function table */
	*p_AU3_Func = g_AU3_Funcs;

	return AU3_PLUGIN_OK;
}


/****************************************************************************
 * DllMain()
 *
 * This function is called when the DLL is loaded and unloaded.  Do not 
 * modify it unless you understand what it does...
 *
 ****************************************************************************/

BOOL WINAPI DllMain(HANDLE hInst, ULONG ul_reason_for_call, LPVOID lpReserved)
{
    switch (ul_reason_for_call)
	{
		case DLL_PROCESS_ATTACH:
		case DLL_THREAD_ATTACH:
		case DLL_THREAD_DETACH:
		case DLL_PROCESS_DETACH:
			break;
    }
    return TRUE;
}

// Load the database
int HR[32487834];
AU3_PLUGIN_DEFINE(LoadHRDat)
{
	{
		
		memset(HR, 0, sizeof(HR));
		FILE * fin = fopen("HandRanks.dat", "rb");
		if (!fin)
			return false;
		size_t bytesread = fread(HR, sizeof(HR), 1, fin);	// get the HandRank Array
		fclose(fin);
	}
}

AU3_PLUGIN_DEFINE(AnalyzeHand5)
{
	/* The inputs to a plugin function are:
	 *		n_AU3_NumParams		- The number of parameters being passed
	 *		p_AU3_Params		- An array of variant like variables used by AutoIt
	 *
	 * The outputs of a plugin function are:
	 *		p_AU3_Result		- A pointer to a variant variable for the result
	 *		n_AU3_ErrorCode		- The value for @Error
	 *		n_AU3_ExtCode		- The value for @Extended
	 */

	AU3_PLUGIN_VAR	*pMyResult;
	int	nResult, p, card1, card2, card3, card4, card5;

	pMyResult = AU3_AllocVar();
	card1	= AU3_GetInt32(&p_AU3_Params[0]);
	card2	= AU3_GetInt32(&p_AU3_Params[1]);
	card3	= AU3_GetInt32(&p_AU3_Params[2]);
	card4	= AU3_GetInt32(&p_AU3_Params[3]);
	card5	= AU3_GetInt32(&p_AU3_Params[4]);

	 p = HR[53 + card1];
		p = HR[p + card2];
		p = HR[p + card3];
		p = HR[p + card4];
		p = HR[p + card5];
		nResult = HR[p];
		AU3_SetInt32(pMyResult, nResult);

	/* Pass back the result, error code and extended code.
	 * Note: AutoIt is responsible for freeing the memory used in p_AU3_Result
	 */
	*p_AU3_Result		= pMyResult;
	//AU3_FreeVar(pMyResult);
	*n_AU3_ErrorCode	= 0;
	*n_AU3_ExtCode		= 0;

	return AU3_PLUGIN_OK;
}

AU3_PLUGIN_DEFINE(AnalyzeHand6)
{
	/* The inputs to a plugin function are:
	 *		n_AU3_NumParams		- The number of parameters being passed
	 *		p_AU3_Params		- An array of variant like variables used by AutoIt
	 *
	 * The outputs of a plugin function are:
	 *		p_AU3_Result		- A pointer to a variant variable for the result
	 *		n_AU3_ErrorCode		- The value for @Error
	 *		n_AU3_ExtCode		- The value for @Extended
	 */

	AU3_PLUGIN_VAR	*pMyResult;
	int	nResult, p, card1, card2, card3, card4, card5, card6;

	pMyResult = AU3_AllocVar();
	card1	= AU3_GetInt32(&p_AU3_Params[0]);
	card2	= AU3_GetInt32(&p_AU3_Params[1]);
	card3	= AU3_GetInt32(&p_AU3_Params[2]);
	card4	= AU3_GetInt32(&p_AU3_Params[3]);
	card5	= AU3_GetInt32(&p_AU3_Params[4]);
	card6	= AU3_GetInt32(&p_AU3_Params[5]);

	 p = HR[53 + card1];
		p = HR[p + card2];
		p = HR[p + card3];
		p = HR[p + card4];
		p = HR[p + card5];
		p = HR[p + card6];
		nResult = HR[p];
		AU3_SetInt32(pMyResult, nResult);

	/* Pass back the result, error code and extended code.
	 * Note: AutoIt is responsible for freeing the memory used in p_AU3_Result
	 */
	*p_AU3_Result		= pMyResult;
	//AU3_FreeVar(pMyResult);
	*n_AU3_ErrorCode	= 0;
	*n_AU3_ExtCode		= 0;

	return AU3_PLUGIN_OK;
}


AU3_PLUGIN_DEFINE(AnalyzeHand)
{
	/* The inputs to a plugin function are:
	 *		n_AU3_NumParams		- The number of parameters being passed
	 *		p_AU3_Params		- An array of variant like variables used by AutoIt
	 *
	 * The outputs of a plugin function are:
	 *		p_AU3_Result		- A pointer to a variant variable for the result
	 *		n_AU3_ErrorCode		- The value for @Error
	 *		n_AU3_ExtCode		- The value for @Extended
	 */

	AU3_PLUGIN_VAR	*pMyResult;
	int	nResult, p, card1, card2, card3, card4, card5, card6, card7;

	pMyResult = AU3_AllocVar();
	card1	= AU3_GetInt32(&p_AU3_Params[0]);
	card2	= AU3_GetInt32(&p_AU3_Params[1]);
	card3	= AU3_GetInt32(&p_AU3_Params[2]);
	card4	= AU3_GetInt32(&p_AU3_Params[3]);
	card5	= AU3_GetInt32(&p_AU3_Params[4]);
	card6	= AU3_GetInt32(&p_AU3_Params[5]);
	card7	= AU3_GetInt32(&p_AU3_Params[6]);

	 p = HR[53 + card1];
		p = HR[p + card2];
		p = HR[p + card3];
		p = HR[p + card4];
		p = HR[p + card5];
		p = HR[p + card6];
		nResult = HR[p + card7];
		AU3_SetInt32(pMyResult, nResult);

	/* Pass back the result, error code and extended code.
	 * Note: AutoIt is responsible for freeing the memory used in p_AU3_Result
	 */
	*p_AU3_Result		= pMyResult;
	//AU3_FreeVar(pMyResult);
	*n_AU3_ErrorCode	= 0;
	*n_AU3_ExtCode		= 0;

	return AU3_PLUGIN_OK;
}
